pub enum IntrError<E> {
Other(E),
Interrupted,
}Expand description
This error type indicates that operation might fail in restartible manner. The most obvious
case is EINTR returned from syscalls when a signal is delivered while doing read.
Variants
Other(E)
The error wasn’t interruption.
Interrupted
An operation was interrupted. This variant means that operation can be retried and it will likely succeed.